@@ -158,7 +158,7 @@ QStringList MainWindow::readantiXRepos()
 // List current repo
 void MainWindow::getCurrentRepo()
 {
-    current_repo  = shell->getCmdOut("grep -m1 '^deb.*/repo/ ' /etc/apt/sources.list.d/antix.list | cut -d' ' -f2 | cut -d/ -f3");
+    current_repo  = shell->getCmdOut("grep -m1 '^deb.*/antix/ ' /etc/apt/sources.list.d/antix.list | cut -d' ' -f2 | cut -d/ -f3");
 }
 
 QString MainWindow::getDebianVersion()
